@@ -8,7 +8,7 @@ def process_item(item):
     if isinstance(item, dict):
         return pairs.combine(
             *[
-                auto_relationship(name, relationship_spec)
+                relationship(name, relationship_spec)
                 for name, relationship_spec in item.items()
             ]
         )
@@ -23,5 +23,5 @@ def alias(alias_or_aliases, item):
     return pairs.alias(alias_or_aliases, process_item(item))
 
 
-def auto_relationship(name, relationship_spec, to_attr=None):
-    return pairs.auto_relationship(name, process(relationship_spec), to_attr)
+def relationship(name, relationship_spec, to_attr=None):
+    return pairs.relationship(name, process(relationship_spec), to_attr)
